package com.shkj.wms.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.shkj.wms.domain.BusinPlcException;
import com.shkj.wms.domain.BusinStockInv;

/**
 * PLC异常内容Mapper接口
 * 
 * @author zjx
 * @date 2023-09-27
 */
public interface BusinPlcExceptionMapper extends BaseMapper<BusinPlcException>
{
    /**
     * 查询PLC异常内容
     * 
     * @param id PLC异常内容主键
     * @return PLC异常内容
     */
    public BusinPlcException selectBusinPlcExceptionById(Long id);

    /**
     * 查询PLC异常内容列表
     * 
     * @param businPlcException PLC异常内容
     * @return PLC异常内容集合
     */
    public List<BusinPlcException> selectBusinPlcExceptionList(BusinPlcException businPlcException);

    /**
     * 新增PLC异常内容
     * 
     * @param businPlcException PLC异常内容
     * @return 结果
     */
    public int insertBusinPlcException(BusinPlcException businPlcException);

    /**
     * 修改PLC异常内容
     * 
     * @param businPlcException PLC异常内容
     * @return 结果
     */
    public int updateBusinPlcException(BusinPlcException businPlcException);

    /**
     * 删除PLC异常内容
     * 
     * @param id PLC异常内容主键
     * @return 结果
     */
    public int deleteBusinPlcExceptionById(Long id);

    /**
     * 批量删除PLC异常内容
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusinPlcExceptionByIds(Long[] ids);
}
